@@ -70,6 +70,7 @@ where
 
 import Control.Exception (throwIO, catch)
 import Control.Monad.State
+import Control.Monad.Reader (ask)
 import Data.Maybe (isNothing, mapMaybe)
 import Network.Gitit.Cache (lookupCache, cacheContents)
 import Network.Gitit.Export (exportFormats)
@@ -85,9 +86,10 @@ import Prelude hiding (catch)
 import System.FilePath
 import Text.HTML.SanitizeXSS (sanitizeBalance)
 import Text.Highlighting.Kate
-import Text.Pandoc hiding (MathML, WebTeX)
+import Text.Pandoc hiding (MathML, WebTeX, MathJax)
 import Text.Pandoc.Shared (ObfuscationMethod(..))
 import Text.XHtml hiding ( (</>), dir, method, password, rev )
+import qualified Data.Text as T
 import qualified Data.ByteString as S (concat)
 import qualified Data.ByteString.Lazy as L (toChunks, fromChunks)
 import qualified Data.FileStore as FS
@@ -336,7 +338,8 @@ pandocToHtml pandocContents = do
   toc <- liftM ctxTOC get
   bird <- liftM ctxBirdTracks get
   cfg <- lift getConfig
-  return $ primHtml $ sanitizeBalance $
+  return $ primHtml $ T.unpack .
+           (if xssSanitize cfg then sanitizeBalance else id) . T.pack $
            writeHtmlString defaultWriterOptions{
                         writerStandalone = True
                       , writerTemplate = "$if(toc)$\n$toc$\n$endif$\n$body$"
@@ -344,6 +347,7 @@ pandocToHtml pandocContents = do
                             case mathMethod cfg of
                                  MathML -> Pandoc.MathML Nothing
                                  WebTeX u -> Pandoc.WebTeX u
+                                 MathJax u -> Pandoc.MathJax u
                                  _      -> JsMath (Just $ base' ++
                                                       "/js/jsMath/easy/load.js")
                       , writerTableOfContents = toc
@@ -449,6 +453,7 @@ addMathSupport c = do
          JsMathScript -> addScripts l ["jsMath/easy/load.js"]
          MathML       -> addScripts l ["MathMLinHTML.js"]
          WebTeX _     -> l
+         MathJax u    -> addScripts l [u]
          RawTeX       -> l
   return c
 
@@ -499,13 +504,17 @@ readerFor pt lhs =
        Textile  -> readTextile defPS
 
 wikiLinksTransform :: Pandoc -> PluginM Pandoc
-wikiLinksTransform = return . bottomUp convertWikiLinks
+wikiLinksTransform pandoc
+  = do cfg <- liftM pluginConfig ask -- Can't use askConfig from Interface due to circular dependencies.
+       return (bottomUp (convertWikiLinks cfg) pandoc)
 
 -- | Convert links with no URL to wikilinks.
-convertWikiLinks :: Inline -> Inline
-convertWikiLinks (Link ref ("", "")) =
+convertWikiLinks :: Config -> Inline -> Inline
+convertWikiLinks cfg (Link ref ("", "")) | useAbsoluteUrls cfg =
+  Link ref (baseUrl cfg </> inlinesToURL ref, "Go to wiki page")
+convertWikiLinks _cfg (Link ref ("", "")) =
   Link ref (inlinesToURL ref, "Go to wiki page")
-convertWikiLinks x = x
+convertWikiLinks _cfg x = x
 
 -- | Derives a URL from a list of Pandoc Inline elements.
 inlinesToURL :: [Inline] -> String
