@@ -42,7 +42,7 @@ data PageType = Markdown | RST | LaTeX | HTML | Textile
 
 data FileStoreType = Git | Darcs | Mercurial deriving Show
 
-data MathMethod = MathML | JsMathScript | WebTeX String | RawTeX
+data MathMethod = MathML | JsMathScript | WebTeX String | RawTeX | MathJax String
                   deriving (Read, Show, Eq)
 
 data AuthenticationLevel = Never | ForModify | ForRead
@@ -132,6 +132,8 @@ data Config = Config {
   -- | Base URL of wiki, for use in feed
   baseUrl              :: String,
   -- | Title of wiki, used in feed
+  useAbsoluteUrls      :: Bool,
+  -- | Should WikiLinks be absolute w.r.t. the base URL?
   wikiTitle            :: String,
   -- | Number of days history to be included in feed
   feedDays             :: Integer,
@@ -140,7 +142,9 @@ data Config = Config {
   -- | Allow PDF export?
   pdfExport            :: Bool,
   -- | Directory to search for pandoc customizations
-  pandocUserData       :: Maybe FilePath
+  pandocUserData       :: Maybe FilePath,
+  -- | Filter HTML through xss-sanitize
+  xssSanitize          :: Bool
   }
 
 -- | Data for rendering a wiki page.
